# What is Alabaster?

Alabaster is a visually (c)lean, responsive, configurable theme for the [Sphinx](http://sphinx-doc.org) documentation system. It is Python 2+3 compatible.

It began as a third-party theme, and is still maintained separately, but as of
Sphinx 1.3, Alabaster is an install-time dependency of Sphinx and is selected
as the default theme.

Live examples of this theme can be seen on [this project’s own website](http://alabaster.readthedocs.io), [paramiko.org](http://paramiko.org),
[fabfile.org](http://fabfile.org) and [pyinvoke.org](http://pyinvoke.org).

For more documentation, please see [http://alabaster.readthedocs.io](http://alabaster.readthedocs.io).

**NOTE**: You can install the development version via `pip install -e
git+https://github.com/bitprophet/alabaster/#egg=alabaster`.
